Module graph

Module graph 

A SaplingSCM Smartlog output graph (sl ssl) is made of two types of items:

  1. Commits: These usually comprise of 2 lines. The first line holds the commit hash, date, author and PR status. The second line holds the commit message. Commits can be local or remote.
  2. Glyphs: These are the graph elements that connect commits to each other.

In our UI, we want to render the exact output of the smartlog. The interactivity we add to the graph makes only commits selectable and actionable. We render the glyphs as well, but they are not made selectable.

Structs

Commit
A graph item representing a commit in the smartlog output. It can be selected and deselected.
Glyph
A graph item representing a glyph in the smartlog output. Usually, this is part of the graph drawing connecting commits together.

Enums

ItemType
An enum of graph item types (using enum_dispatch).

Traits

Item
A trait for graph items (using enum_dispatch).